@@ -12,10 +12,10 @@ fn main() {
         .write_all(include_bytes!("xtensa.in.x"))
         .unwrap();
 
-    let exception_source = match (cfg!(feature = "lx6"), cfg!(feature = "lx106")) {
-        (true, false) => &include_bytes!("exception-lx6.x")[..],
-        (false, true) => &include_bytes!("exception-lx106.x")[..],
-        _ => panic!("Either the lx6 or lx106 feature has to be enabled"),
+    let exception_source = match (cfg!(feature = "esp32"), cfg!(feature = "esp8266")) {
+        (true, false) => &include_bytes!("exception-esp32.x")[..],
+        (false, true) => &include_bytes!("exception-esp8266.x")[..],
+        _ => panic!("Either the esp32 or esp8266 feature must be enabled"),
     };
 
     File::create(out.join("exception.x"))
